@@ -1,2 +1,5 @@
+"""
+.. include:: ../README.md
+"""
 from __future__ import annotations
 __all__ = ['froc', 'count']
