@@ -201,22 +201,10 @@ def generate_bootstrap_froc_curves(
 
         if test_ann is not None:
             for t_ann, c in zip(test_ann, colors):
+                t_ann, label = t_ann
                 t_pr = transform_gt_into_pr(t_ann, gt_ann)
                 stats = froc_point(gt_ann, t_pr, .5, use_iou, iou_thres)
                 _lls_accuracy, _nlls_per_image = calc_scores(stats, {}, {})
-                label = t_ann.split('/')[-1].replace('.json', '')
-                if 'bobe' in label:
-                    label = 'bobe'
-                elif 'istvan' in label:
-                    label = 'istvan'
-                elif 'tea' in label:
-                    label = 'tea'
-                elif 'eszter' in label:
-                    label = 'eszter'
-                elif 'maryam' in label:
-                    label = 'maryam'
-                elif 'lea' in label:
-                    label = 'lea'
                 ax.plot(
                     _nlls_per_image[cat_id][0],
                     _lls_accuracy[cat_id][0],
